pub type UserSpecializeFn = fn(&(dyn Any + 'static), &mut RenderPipelineDescriptor, &MeshVertexBufferLayoutRef, ErasedMaterialPipelineKey) -> Result<(), SpecializedMeshPipelineError>;Expand description
A type erased function pointer for specializing a material prepass pipeline. The implementation is expected to:
- Look up the appropriate specializer from the world
- Downcast the erased key to the concrete key type
- Call
SpecializedMeshPipelines::specializewith the specializer and return the resulting pipeline id